﻿;========================================================================================================================================
; Create the system database procedure
;========================================================================================================================================

Procedure OpenSystemDatabaseFile()
  
  ;----------------------------------------------------------------------------------------------
  ; Proceed if there is a predefined project directory
  ;----------------------------------------------------------------------------------------------
  
  OutputFileName.s = Program\ModuleDirectory + "_OpenSystemDatabase.pbi"
  
  ;----------------------------------------------------------------------------------------------
  ; 
  ;----------------------------------------------------------------------------------------------
  
  If OutputFileName.s
    
    ;--------------------------------------------------------------------------------------------
    ; Create the output file to save to
    ;--------------------------------------------------------------------------------------------
    
    OutputFileHandle.i = CreateFile(#PB_Any, OutputFileName.s)
    
    ;--------------------------------------------------------------------------------------------
    ; 
    ;--------------------------------------------------------------------------------------------
    
    If OutputFileHandle.i
      
      ;******************************************************************************************
      ; Write the keyboard shortcuts table out
      ; 
      ; 
      ; This always goes into %INCLUDES%\Database
      ;******************************************************************************************
      
      WriteHeadingToOutputFile(OutputFileHandle.i, "; Keyboard shortcuts table procedure")
      
      WriteStringN(OutputFileHandle.i,            "PROCEDURE OpenSystemDatabase()")
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i, "  ;------------------------------------------------------------------------------------------------")
      
      WriteStringN(OutputFileHandle.i, "  ; ")
      
      WriteStringN(OutputFileHandle.i, "  ;------------------------------------------------------------------------------------------------")

      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "  Query.s = " + Chr(34) + "CREATE TABLE IF NOT EXISTS KeyboardShortcuts(" + Chr(34))
      
      WriteStringN(OutputFileHandle.i,     "")
      
      LastElementIndex = ListSize(Keys.s()) - 1
      
      Counter = 0
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          Index = ListIndex(Keys.s())
          
          If Index & 3 = 3 Or Index = LastElementIndex
            
            WriteStringN(OutputFileHandle.i,      "  Query.s + " + Chr(34) + OutString.s + Keys()\KeyDataText + " TEXT, " + Chr(34))
            
            WriteStringN(OutputFileHandle.i,     "")
                  
            OutString.s = ""
            
          Else
            
            OutString.s + Keys()\KeyDataText + " TEXT, "
            
          EndIf
          
        EndIf
        
      Next

      WriteStringN(OutputFileHandle.i,            "  Query.s + " + Chr(34) + "Record INTEGER PRIMARY KEY AUTOINCREMENT)" + Chr(34))
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i, "  ;------------------------------------------------------------------------------------------------")
      
      WriteStringN(OutputFileHandle.i, "  ; ")
      
      WriteStringN(OutputFileHandle.i, "  ;------------------------------------------------------------------------------------------------")

      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "  If DatabaseUpdate(Program\DatabaseHandle, Query.s)")
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "    If CountRecords(" + Chr(34) + "SELECT COUNT(Record) AS TotalRecs FROM KeyboardShortcuts" + Chr(34) + ") = "  + Chr(34) + "0" + Chr(34))
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "      Query.s = " + Chr(34) + "INSERT INTO KeyboardShortcuts("  + Chr(34))

      WriteStringN(OutputFileHandle.i,     "")
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          Index = ListIndex(Keys.s())
          
          If Index & 3 = 3 Or Index = LastElementIndex
            
            If Index = LastElementIndex
              
              WriteStringN(OutputFileHandle.i,      "      Query.s + " + Chr(34) +  OutString.s + Keys()\KeyDataText + ") " + Chr(34))
              
              WriteStringN(OutputFileHandle.i,     "")
      
            Else
              
              WriteStringN(OutputFileHandle.i,      "      Query.s + " + Chr(34) +  OutString.s + Keys()\KeyDataText + ", " + Chr(34))
              
              WriteStringN(OutputFileHandle.i,     "")
      
            EndIf
            
            OutString.s = ""
            
          Else
            
            OutString.s + Keys()\KeyDataText + ", "
            
          EndIf
          
        EndIf
        
      Next

      WriteStringN(OutputFileHandle.i,            "      Query.s + " + Chr(34) + "VALUES("  + Chr(34))
      
      WriteStringN(OutputFileHandle.i,     "")
      
      ForEach Keys.s()
        
        If Left(Keys()\KeyDataName, 1) <> "~" And Right(Keys()\KeyDataName, 1) <> "~"
          
          Index = ListIndex(Keys.s())
          
          If Index & 3 = 3 Or Index = LastElementIndex
            
            If Index = LastElementIndex
              
              WriteStringN(OutputFileHandle.i,      "      Query.s + " + Chr(34) + OutString.s + "'" + Keys()\KeyDataValue + "')"   + Chr(34))
              
              WriteStringN(OutputFileHandle.i,     "")
              
            Else
              
              WriteStringN(OutputFileHandle.i,      "      Query.s + " + Chr(34) + OutString.s + "'" + Keys()\KeyDataValue + "', "  + Chr(34))
              
              WriteStringN(OutputFileHandle.i,     "")
      
            EndIf
            
            OutString.s = ""
            
          Else
            
            OutString.s +  "'" + Keys()\KeyDataValue + "', "
            
          EndIf
          
        EndIf
        
      Next

      WriteStringN(OutputFileHandle.i,            "      If DatabaseUpdate(Program\DatabaseHandle, Query.s)")
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "      EndIf")
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "    EndIf")
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "  EndIf")
      
      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "  ;------------------------------------------------------------------------------------------------")
      
      WriteStringN(OutputFileHandle.i,            "  ; ")
      
      WriteStringN(OutputFileHandle.i,            "  ;------------------------------------------------------------------------------------------------")

      WriteStringN(OutputFileHandle.i,     "")
      
      WriteStringN(OutputFileHandle.i,            "EndProcedure")
      
      ;------------------------------------------------------------------------------------------
      ; Close the output file as we are finished writing to it
      ;------------------------------------------------------------------------------------------
      
      CloseFile(OutputFileHandle.i)
      
      ;------------------------------------------------------------------------------------------
      ; 
      ;------------------------------------------------------------------------------------------
      
    Else
      
      SetGadgetText(#Gadget_ShortCutter_messages, Str(OutputFileHandle.i) + " could not be created.")
      
    EndIf
    
    ;--------------------------------------------------------------------------------------------
    ; 
    ;--------------------------------------------------------------------------------------------
      
  Else
    
    SetGadgetText(#Gadget_ShortCutter_messages, OutputFileName.s + " does not exist.")
    
  EndIf
  
  ;----------------------------------------------------------------------------------------------
  ; 
  ;----------------------------------------------------------------------------------------------
    
EndProcedure

; IDE Options = PureBasic 5.11 (Windows - x86)
; CursorPosition = 227
; FirstLine = 198
; Folding = -
; EnableXP